-- sql
-- $Source: fd2gm_drugs.sql
-- $Revision: 1.1 
-- $Author: Jim Busser, GNUmed and FreeDiams projects
-- ---------------------------
-- Description:
-- script for importing FreeDiams-sourced drug 'molecule' data
-- … for import into GNUmed ref.consumable.substances
-- … renamed as 'install-data-pack.sql' within GNUmed data packs
-- … configurational name = 'Canadian non-brand drug info 2011'
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--	git://gitorious.org/gnumed/gnumed.git
--	http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
-- 	http://www.gnumed.de/downloads/data/data-packs.conf
-- 	http://wiki.gnumed.de
-- FreeDiams
-- 	http://www.freemedforms.com/en/manuals/freediams/start
-- ----------------------


-- -----------------------------------------------------------------------------
-- ************************************************************
-- create staging table (if it does not already exist)
-- ************************************************************
-- alternative clause:
--     if not exists(SELECT true FROM pg_tables
--      WHERE tablename = 'consumable_substance' AND schemaname = 'staging') then
-- From:
-- 	http://stackoverflow.com/questions/435424/
--	postgresql-how-to-create-table-only-if-it-does-not-already-exist
-- -----------------------------------------------------------------------------
create or replace function update_the_db() returns void as
$$
begin

    if not exists(select * from information_schema.tables 
        where 
            table_catalog = CURRENT_CATALOG and table_schema = CURRENT_SCHEMA
            and table_name = 'consumable_substance') then

        create table staging.consumable_substance
         (
	    description text,
	    atc_code text,
	    amount numeric,
	    unit text
	);

    end if;

end;
$$
LANGUAGE 'plpgsql';
SELECT update_the_db();
DROP FUNCTION update_the_db();

-- -----------------------------------------------------------------------------
-- ************************************************************
--  truncate (delete any and all records from) staging table
-- ************************************************************
--
-- -----------------------------------------------------------------------------
TRUNCATE TABLE staging.consumable_substance


-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- ~ 6354 rows
-- caveats:
-- some records in Canadian HC DPD have zero strength
-- three are allergy-testing related and one was a technical disinfectant(s) having zero strength
-- if these would be future-disallowed in GNUmed they may need pruning e.g.
-- review:	select * from subs where amount = 0 ;
-- delete disinfectants:	delete from subs where amount = 0 and position('V07AV' in atc_code) = 1 ;
--
-- -----------------------------------------------------------------------------
\COPY staging.consumable_substance FROM '\consumable_substances_en_CA.txt' WITH NULL AS '' CSV


-- -----------------------------------------------------------------------------
-- ************************************************************
-- transfer from staging table into ref.consumable_substance
-- ************************************************************
-- if does not already exist, and provided amounts are >= 0
-- -----------------------------------------------------------------------------

INSERT INTO ref.consumable_substance (
	description,
	atc_code,
	amount,
	unit
)
SELECT
		initcap(description),
		atc_code,
		amount,
		lower(unit)
	FROM
		staging.consumable_substance s_cs
	WHERE
		NOT EXISTS (
			SELECT 1
			FROM
				ref.consumable_substance r_cs
			WHERE
				r_cs.description = s_cs.description
					AND
				r_cs.amount = s_cs.amount
					AND
				r_cs.unit = s_cs.unit
			LIMIT 1
		)
		AND s_cs.amount >= 0
;

.exit
-- end